/* A Bison parser, made by GNU Bison 2.5.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NULLV = 258,
     INTEGER = 259,
     REAL = 260,
     STRING = 261,
     SYMBOL = 262,
     LITERAL = 263,
     WHILE = 264,
     FOR = 265,
     IF = 266,
     SUB = 267,
     FOREACH = 268,
     LOCAL = 269,
     GLOBAL = 270,
     BREAK = 271,
     RETURN = 272,
     IFI = 273,
     ELSE = 274,
     BOOLOR = 275,
     BOOLAND = 276,
     IJOIN = 277,
     ORASSIGN = 278,
     ISHL = 279,
     ISHR = 280,
     IBITXOR = 281,
     IBITOR = 282,
     IBITAND = 283,
     IMOD = 284,
     IDIV = 285,
     IMUL = 286,
     ISUB = 287,
     IADD = 288,
     DEC = 289,
     INC = 290,
     RANGE = 291,
     ARROW = 292,
     NUMLE = 293,
     NUMGE = 294,
     NUMNE = 295,
     STRNE = 296,
     NUMEQ = 297,
     STREQ = 298,
     JOIN = 299,
     AMPERSAND = 300,
     BITXOR = 301,
     BITOR = 302,
     SHR = 303,
     SHL = 304,
     POW = 305,
     MOD = 306,
     INVCALL = 307,
     UMINUS = 308
   };
#endif
/* Tokens.  */
#define NULLV 258
#define INTEGER 259
#define REAL 260
#define STRING 261
#define SYMBOL 262
#define LITERAL 263
#define WHILE 264
#define FOR 265
#define IF 266
#define SUB 267
#define FOREACH 268
#define LOCAL 269
#define GLOBAL 270
#define BREAK 271
#define RETURN 272
#define IFI 273
#define ELSE 274
#define BOOLOR 275
#define BOOLAND 276
#define IJOIN 277
#define ORASSIGN 278
#define ISHL 279
#define ISHR 280
#define IBITXOR 281
#define IBITOR 282
#define IBITAND 283
#define IMOD 284
#define IDIV 285
#define IMUL 286
#define ISUB 287
#define IADD 288
#define DEC 289
#define INC 290
#define RANGE 291
#define ARROW 292
#define NUMLE 293
#define NUMGE 294
#define NUMNE 295
#define STRNE 296
#define NUMEQ 297
#define STREQ 298
#define JOIN 299
#define AMPERSAND 300
#define BITXOR 301
#define BITOR 302
#define SHR 303
#define SHL 304
#define POW 305
#define MOD 306
#define INVCALL 307
#define UMINUS 308




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 2068 of yacc.c  */
#line 86 "mpsl.y"

	mpdm_t v;	/* a simple value */
	mpdm_t ins;	/* an 'instruction': [ opcode, args ] */



/* Line 2068 of yacc.c  */
#line 163 "y.tab.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE yylval;


